summaryrefslogtreecommitdiffstats
path: root/buildtools/autotools/autoprojectwidget.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:15:35 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:15:35 -0600
commitf78eb03afb8c9a380985d26286afc40b4c89b292 (patch)
tree3c087e2f119e645c902958c3bc3c802abf078ad0 /buildtools/autotools/autoprojectwidget.h
parentda1941ccadffe5ae70ee111c53f0ec2b3d990869 (diff)
downloadtdevelop-f78eb03afb8c9a380985d26286afc40b4c89b292.tar.gz
tdevelop-f78eb03afb8c9a380985d26286afc40b4c89b292.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'buildtools/autotools/autoprojectwidget.h')
-rw-r--r--buildtools/autotools/autoprojectwidget.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/buildtools/autotools/autoprojectwidget.h b/buildtools/autotools/autoprojectwidget.h
index 7859f472..8ad8bf7e 100644
--- a/buildtools/autotools/autoprojectwidget.h
+++ b/buildtools/autotools/autoprojectwidget.h
@@ -36,12 +36,12 @@ class AutoDetailsView;
class SubprojectItem;
class TargetItem;
class FileItem;
-class KAction;
+class TDEAction;
class TQDomElement;
class TQToolButton;
class TQStringList;
class TQFocusEvent;
-class KListViewItem;
+class TDEListViewItem;
class TQListViewItem;
class MakefileHandler;
@@ -63,7 +63,7 @@ public:
*/
TQStringList allSubprojects();
/**
* A list of all Subproject items in the overview KListView
*/
TQPtrList <SubprojectItem> allSubprojectItems();
/**
@@ -63,7 +63,7 @@ public:
TQStringList allSubprojects();
/**
- * A list of all Subproject items in the overview KListView
+ * A list of all Subproject items in the overview TDEListView
*/
TQPtrList <SubprojectItem> allSubprojectItems();